searchData={"items":[{"type":"module","title":"PhoenixFormAwesomplete","doc":"PhoenixFormAwesomplete is a [Phoenix form helper](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) \nthat utilizes Lea Verou's autocomplete / autosuggest / typeahead / \ninputsearch [Awesomplete widget](https://leaverou.github.io/awesomplete/index.html).\n\nIt comes with an AwesompleteUtil [javascript library](https://nico-amsterdam.github.io/awesomplete-util/index.html) \nwhich adds the following features:\n\n- Dynamic remote data loading; based on what is typed-in it performs an ajax lookup.\n- Allow HTML markup in the shown items. Show value with description. Optionally search in the description text.\n- Show when there is an exact match.\n- Show when there isn't a match.\n- When there is an exact match show related data (supplied in the remote data) in other parts of the page.\n- Select the highlighted item with the tab-key. \n\n[Online demo](https://nico-amsterdam.github.io/awesomplete-util/phoenix.html)","ref":"PhoenixFormAwesomplete.html"},{"type":"module","title":"Use cases - PhoenixFormAwesomplete","doc":"An autocomplete component is a free text input that provides suggestions while typing. It is not necessary to choose one of the suggestions, but of course a form validator can reject disallowed input.\n\nThe HTML combobox is very suitable for this. The combobox looks like a   but it doesn't limit the input. It consists of a   element combined with a   with   and   elements. When the standard combobox doesn't meet the requirements, a solution involving javascript can be used.\nWhen using LiveView the datalist of the HTML combobox can be made dynamic, with different suggestions based on the typed input. Like [this dictionary search demo](https://github.com/chrismccord/phoenix_live_view_example/blob/master/lib/demo_web/live/search_live.ex). And there are some fancy LiveView components available like the [Live Select](https://hex.pm/packages/live_select) with a stylish multiselect. These solutions are dynamic and don't necessary require a web service. However, you have to handle the input state on the server (again like [this](https://github.com/chrismccord/phoenix_live_view_example/blob/master/lib/demo_web/live/search_live.ex#L22)) and it only works in LiveView components.\n\nThis Awesomplete component can be applied for these cases:\n- Outside and inside LiveView. It is even possible to make a HEEx fragment with autocomplete that works in both. See the next chapter.\n- It is specially suitable for suggestions supplied by HTTP web services that produce JSON.\n- It can give suggestions for a list with multiple values.\n- It doesn't force the user to pick on of the suggestions; other values can be entered.\n- It can highlight the input field if there is a match or no match.\n- The list with suggestions can be customized, for example to show an extra description.\n- The client stops interacting with the backend and filters on it's own when enough characters have been typed and the suggestionlist has become smaller than the search result limit.\n- It can fill dependend readonly fields/tags. The typical example would be a productcode with a product description shown in order lines. For the existing order lines the database can join the product description to be shown on the screen, but for new entries and when changing the productcode it has te be dynamicly looked up. This can be done while typing. After leaving the input field, the product description stays visible on the screen.","ref":"PhoenixFormAwesomplete.html#module-use-cases"},{"type":"module","title":"Phoenix function components - PhoenixFormAwesomplete","doc":"In HEEx templates and ~H sigils, function components offer a method of reuse.  \nAnd they make the HEEx markup arguable more readable.\n\n#","ref":"PhoenixFormAwesomplete.html#module-phoenix-function-components"},{"type":"module","title":"Outside LiveView, a.k.a. \"dead\" views - PhoenixFormAwesomplete","doc":"When currently using Awesomplete, the templates can easily be rewritten to use\nfunction components. The input tag is seperated from the script tag of Awesomplete,\nwhich makes it easier to customize the style of the input field.\n\nExample:\n\n```elixir\n \n   \n   \n \n```\n\nThe nonce in the example above, is to allow inline script to be executed\nin combination with a Content-Security-Policy that doesn't \nallow unsafe evals or unsafe inline scripts.\n\n#","ref":"PhoenixFormAwesomplete.html#module-outside-liveview-a-k-a-dead-views"},{"type":"module","title":"Both inside and outside LiveView - PhoenixFormAwesomplete","doc":"For security reasons, LiveView doesn't execute the javascript in dynamicly loaded script tags. Adding new javascript after the page is loaded via the HTTP-request is what every malicious Cross Site Scripting (XSS) code tries to do. Via the Content-Security-Policy HTTP-header, it is possible to prevent dynamicly loaded script to be executed.\nIn LiveView the javascript code is loaded as a static asset, and \n [client hooks via the phx-hook](https://hexdocs.pm/phoenix_live_view/js-interop.html#client-hooks-via-phx-hook) can be used to execute javascript code for\n dynamicly added DOM elements.\nInstead of generating javascript code for every autocomplete field, a javascript hook\nis used which gets it's parameters at runtime. This javascript hook can handle the straightforward cases, but could need some tweaking for the corner cases. If these corner cases are complex and only applicable for a small subset of pages/components, you might consider to split off new client hooks.\n\nThe beauty of the client hooks is that this can be used both inside and outside LiveView as they both use the mounted callback. This makes it possible define a reusable component with autocomplete fields, which can be incorporated inside and outside LiveView.\n\nExample:\n\n```elixir\n \n   \n\n     \n\n     \n\n   \n \n```","ref":"PhoenixFormAwesomplete.html#module-both-inside-and-outside-liveview"},{"type":"module","title":"Security - PhoenixFormAwesomplete","doc":"#","ref":"PhoenixFormAwesomplete.html#module-security"},{"type":"module","title":"Content-Security-Policy - PhoenixFormAwesomplete","doc":"As mentioned before, use a safe Content-Security-Policy (CSP):\n- do not allow unsafe eval\n- do not allow unsafe inline script\n- In the connect_src whitelist only the url's of trusted sites. Make sure that the url's of Awesomplete cannot be tampered with.\n\n#","ref":"PhoenixFormAwesomplete.html#module-content-security-policy"},{"type":"module","title":"Trusted web services - PhoenixFormAwesomplete","doc":"Use only trusted web services. As an extra safety measure it possible to sanatize or escape HTML in the JSON responses via a convertResponse function. As external web services \nare used directly, than this service will not only see the searched text but also the\nclient IP address.","ref":"PhoenixFormAwesomplete.html#module-trusted-web-services"},{"type":"module","title":"Installation - PhoenixFormAwesomplete","doc":"#","ref":"PhoenixFormAwesomplete.html#module-installation"},{"type":"module","title":"Installation for use outside LiveView only - PhoenixFormAwesomplete","doc":"- Add `phoenix_form_awesomplete`to the list of dependencies in `mix.exs`:\n  ```elixir\n  def deps do\n    [\n    {:phoenix_form_awesomplete, \"~> 0.2\"}\n    ]\n  end\n  ```\n- run\n  ```sh\n  mix deps.get\n  ```\n- Add lib/ _web/components/[awesomplete_script_components.ex](https://github.com/nico-amsterdam/phoenix-csp-outside-liveview/blob/main/hello_world/lib/hello_world_web/components/awesomplete_script_components.ex).\n\n  Rename the module to match your project. \n- Add these function components in lib/ _web/components/core_components.ex:\n  ```elixir\n  @awesomplete  Web.AwesompleteScriptComponents\n\n  defdelegate autocomplete(assigns), to: @awesomplete\n  defdelegate copy_value_to_id(assigns), to: @awesomplete\n  defdelegate copy_value_to_field(assigns), to: @awesomplete\n  ``` \n- copy [awesomplete.css](https://github.com/LeaVerou/awesomplete/blob/gh-pages/awesomplete.css) to assets/css \n- copy [awesomplete-util.min.js](https://nico-amsterdam.github.io/awesomplete-util/js/awesomplete-util.min.js) to assets/vendor\n- copy [awesomplete-v2020.min.js](https://nico-amsterdam.github.io/awesomplete-util/js/awesomplete-v2020.min.js) to assets/vendor\n- create assets/js/awesomplete.js:\n  ```elixir\n  import Awesomplete from '../vendor/awesomplete-v2020.min.js'\n  import AwesompleteUtil from '../vendor/awesomplete-util.min.js'\n\n  // expose Awesomplete\n  window.Awesomplete = Awesomplete\n  window.AwesompleteUtil = AwesompleteUtil\n  ```\n- in config/config.exs add awesomplete.css and awesomplete.js in the esbuild config:\n  ```elixir\n  ~w(js/app.js js/awesomplete.js css/awesomplete.css --bundle --target=es2017 --outdir=../priv/static/assets --external:/fonts/* --external:/images/*),\n  ```\n- add in assets/css/app.css\n  ```elixir\n  @import \"awesomplete.css\";\n  ```\n- add styles in assets/css/app.css\n  ```css\n  /*\n  * Awesomplete\n  */\n  div.awesomplete {display: block}\n  div.awesomplete ul li p {display: block; font-size: small; margin-left: 1em}\n  div.awesomplete .awe-found {border: 2px solid green}\n  .hide-not-found div.awesomplete .awe-not-found {border-color: lightblue}\n  div.awesomplete .awe-not-found {border: 2px solid red}\n  .awe-btn .caron { pointer-events: none }\n  ```\n- In lib/ _web/components/layouts/root.html.heex add this to the head:\n  ```elixir\n    \n   \n  ```\n- run\n  ```sh\n  mix phx.server\n  ```\n\n\n\n#","ref":"PhoenixFormAwesomplete.html#module-installation-for-use-outside-liveview-only"},{"type":"module","title":"Installation for using both inside and outside LiveView - PhoenixFormAwesomplete","doc":"- Add the [Hooks Autocomplete and AutocompleteCopyValueToId](https://github.com/nico-amsterdam/todo_trek/blob/main/assets/js/app.js#L78) in assets/js/app.js\n- Add lib/ _web/components/[awesomplete_components.ex](https://github.com/nico-amsterdam/todo_trek/blob/main/lib/todo_trek_web/components/awesomplete_components.ex) \n  \n  Rename the module to match your project. \n- Add these function components in lib/ _web/components/core_components.ex:\n  ```elixir\n  @awesomplete  Web.AwesompleteComponents\n\n  defdelegate autocomplete(assigns), to: @awesomplete\n  defdelegate copy_value_to_id(assigns), to: @awesomplete\n  defdelegate copy_value_to_field(assigns), to: @awesomplete\n  ```\n- copy [awesomplete-util.min.js](https://nico-amsterdam.github.io/awesomplete-util/js/awesomplete-util.min.js) to assets/vendor\n- copy [awesomplete-v2020.min.js](https://nico-amsterdam.github.io/awesomplete-util/js/awesomplete-v2020.min.js) to assets/vendor\n- in assets/js/app.js add:\n  ```elixir\n  import Awesomplete from '../vendor/awesomplete-v2020.min.js'\n  import AwesompleteUtil from '../vendor/awesomplete-util.min.js'\n  ```\n- copy [awesomplete.css](https://github.com/LeaVerou/awesomplete/blob/gh-pages/awesomplete.css) to assets/css \n- in config/config.exs add awesomplete.css in the esbuild config:\n  ```elixir\n  ~w(js/app.js css/awesomplete.css --bundle --target=es2017 --outdir=../priv/static/assets --external:/fonts/* --external:/images/*),\n  ```\n- add in assets/css/app.css\n  ```elixir\n  @import \"awesomplete.css\";\n  ```\n- add styles in assets/css/app.css\n  ```css\n  /*\n  * Awesomplete\n  */\n  div.awesomplete {display: block}\n  div.awesomplete ul li p {display: block; font-size: small; margin-left: 1em}\n  div.awesomplete .awe-found {border: 2px solid green}\n  .hide-not-found div.awesomplete .awe-not-found {border-color: lightblue}\n  div.awesomplete .awe-not-found {border: 2px solid red}\n  .awe-btn .caron { pointer-events: none }\n  ```\n- lib/ _web/components/layouts/root.html.heex add this to the head:\n  ```elixir\n   \n  ```\n- run\n  ```sh\n  mix phx.server\n  ```","ref":"PhoenixFormAwesomplete.html#module-installation-for-using-both-inside-and-outside-liveview"},{"type":"module","title":"PhoenixFormAwesomplete raw example - PhoenixFormAwesomplete","doc":"#","ref":"PhoenixFormAwesomplete.html#module-phoenixformawesomplete-raw-example"},{"type":"module","title":"IEx - PhoenixFormAwesomplete","doc":"iex> {:safe, [input, script]} = PhoenixFormAwesomplete.awesomplete(:user, :drinks,\n    ...> [\"data-list\": \"beer, gin, soda, sprite, water, vodga, whine, whisky\"], \n    ...> %{ minChars: 1 } )\n    iex> to_string input\n    \" \n    \" id=\\\"user_drinks\\\" name=\\\"user[drinks]\\\" type=\\\"text\\\">\"\n    iex> script\n    \" AwesompleteUtil.start('#user_drinks', {}, {minChars: 1}); \"\n\nThe first three parameters are passed on unchanged to the Phoenix form [text_input](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html#text_input/3) which generates the input tag.\n`minChars` is an option for the Awesomplete object which is started with inline javascript.\nJust adding the `multiple` option changes the generated javascript code completely, the PhoenixFormAwesomplete module\ntakes care of that. \nInstead of an server side generated data-list it is possible to specify an url of a JSON web service and \nlet the client-code lookup the data list on-demand while typing. \nLook at the [live examples](https://nico-amsterdam.github.io/awesomplete-util/phoenix.html) with code.\n\n\nIt is possible to use aliases for the javascript library references in the generated code \nvia the environment variables `util` and `awesomplete`.\nThe default names, `AwesompleteUtil` and `Awesomplete` respectively, are a bit long.\nThis can shorten the average page size.\nFor example use this javascript: \n     var AU = AwesompleteUtil, AW = Awesomplete; \nand change the variables via the application config:\n     :phoenix_form_awesomplete, util:         \"AU\"\n     :phoenix_form_awesomplete, awesomplete:  \"AW\"\nAfter changing the config/config.exs run:\n     mix deps.compile --force phoenix_form_awesomplete","ref":"PhoenixFormAwesomplete.html#module-iex"},{"type":"function","title":"PhoenixFormAwesomplete.awesomplete/4","doc":"This method generates an input tag and inline javascript code that starts Awesomplete. Use this in (L)EEx templates. For HEEx templates it recommended to use <.input in combination with awesomplete_script/2.\n\nAwesomplete options:\n * `ajax`            - Replace ajax function. Supplied function receives these parameters: (url, urlEnd, val, fn, xhr). fn is the callback function. Default: AwesompleteUtil.ajax. \n * `assign`          - Assign the Awesomplete object to a variable. true/false/name. If true the variable name will be 'awe\\_' + id of input tag. Default: false\n * `autoFirst`       - true/false. Automatically select the first element. Default: false. \n * `combobox`        - Id of the combobox button. true/false/id. If true the assumed button id is 'awe\\_btn\\_' + id of the input tag. Default: false\n * `convertInput`    - Convert input function. Internally convert input for comparison with the data list items. By default it trims the input and converts it to lowercase for a case-insensitive comparison.\n * `convertResponse` - Convert JSON response from ajax calls. This function is called with the parsed JSON, and allows conversion of the data before further processing. Default: nil - no conversion. \n * `data`            - Data function as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility)\n * `debounce`        - Time in milliseconds to wait for additional user input before doing the ajax call to retrieve suggestions. It limits the rate at which the json service is called per user session.\n * `descr`           - Name of the field in the data list (the JSON response) that contains the description text to show below the value in the suggestion list. Default: no description\n * `descrSearch`     - true/false. Filter must also search the input value in the description field. Default: false\n * `filter`          - Filter function as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility). Mostly Awesomplete.FILTER\\_STARTSWITH or Awesomplete.FILTER\\_CONTAINS. If label is different as value, filter on value with AweompleteUtil.filterStartsWith or AwesompleteUtil.filterContains.\n * `item`            - Item function as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility). Default is to highlight all occurrences of the input text. Use AwesompleteUtil.itemStartsWith if that matches with the used filter.\n * `label`           - Name of the field in the data list (the JSON response) that contains the text that should be shown instead of the value. \n * `list`            - Data list as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility).\n * `loadall`         - true/false. Use true if the data list contains all items, and the input value should not be used in ajax calls. Default: false\n * `limit`           - number. If a limit is specified, and the number of items returned by the server is equal or more as this limit, the AwesompleteUtil code assumes that there are more results, so it will re-query if more characters are typed to get more refined results. The limit:1 tells that not more than 1 result is expected, so the json service doesn’t have to return an array. With limit:0 it will always re-query if more characters are typed and the result doesn't have to be an array either. Limit:-1 will always requery and the expected result is an array. When no limit is specified, the code assumes that all possible suggestions are returned based on the typed characters, and it will not re-query if more characters are typed. It uses the specified filter for the suggestions in the dropdown. Default: no limit \n * `maxItems`        - Maximum number of suggestions to display. Default: 10 \n * `minChars`        - Minimum characters the user has to type before the autocomplete popup shows up. Default: 2 \n * `multiple`        - true/false/characters. Separators to allow multiple values. If true, the separator will be the space character. Default: false\n * `nonce`           - Content-Security-Policy nonce attribute for the script tag. Default: no nonce. If specified it must contain a non-empty value.\n * `prepop`          - true/false. If true do lookup initial/autofilled value and send awesomplete-prepop event. Default: false \n * `replace`         - Replace function as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility)\n * `sort`            - Sort function as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility)\n * `url`             - url for ajax calls.\n * `urlEnd`          - Addition at the end of the url of the ajax call, after the input value. \n * `value`           - Name of the field in the data list (the JSON response) that contains the value.","ref":"PhoenixFormAwesomplete.html#awesomplete/4"},{"type":"function","title":"Example - PhoenixFormAwesomplete.awesomplete/4","doc":"iex> {:safe, [inp, scr]} = PhoenixFormAwesomplete.awesomplete(:user, :eyes, \n    ...> [\"data-list\": \"blue, brown, green\"],\n    ...>  %{ minChars: 1, multiple: \",;\", nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\" } )\n    iex> to_string inp\n    \" \"\n    iex> scr\n    \" AwesompleteUtil.start('#user_eyes', \"   \n    \"{convertInput: function(input) {\"  \n    \" return input.replace(/[,;]\\\\s*$/, '').match(/[^,;]*$/)[0].trim().toLowerCase(); }}, \"  \n    \"{minChars: 1, \"   \n    \"replace: function(data) {\"  \n    \" var text=data.value;\"   \n    \" this.input.value = this.input.value.match(/^.+[,;]\\\\s*|/)[0] + text + ', '; }, \"  \n    \"filter: function(data, input) {\"  \n    \" return Awesomplete.FILTER_CONTAINS(data, input.match(/[^,;]*([,;]\\\\s*)?$/)[0]); }, \"  \n    \"item: function(text, input) {\"  \n    \" return AwesompleteUtil.itemContains(text, input.match(/[^,;]*([,;]\\\\s*)?$/)[0]); }});\"  \n    \" \"","ref":"PhoenixFormAwesomplete.html#awesomplete/4-example"},{"type":"function","title":"PhoenixFormAwesomplete.awesomplete_js/2","doc":"This method generates javascript code for using Awesomplete(Util).","ref":"PhoenixFormAwesomplete.html#awesomplete_js/2"},{"type":"function","title":"Example - PhoenixFormAwesomplete.awesomplete_js/2","doc":"iex> ff = %Phoenix.HTML.FormField{form: \"user\", field: \"hobby\", id: \"user_hobby\", name: \"user[hobby]\", errors: [], value: nil} \n    iex> PhoenixFormAwesomplete.awesomplete_js(ff , %{ minChars: 1 } )    \n    \"AwesompleteUtil.start('#user_hobby', {}, {minChars: 1});\"","ref":"PhoenixFormAwesomplete.html#awesomplete_js/2-example"},{"type":"function","title":"PhoenixFormAwesomplete.awesomplete_js/3","doc":"This method generates javascript code for using Awesomplete(Util).","ref":"PhoenixFormAwesomplete.html#awesomplete_js/3"},{"type":"function","title":"Example - PhoenixFormAwesomplete.awesomplete_js/3","doc":"iex> PhoenixFormAwesomplete.awesomplete_js(:user, :hobby, %{ minChars: 1 } )\n    \"AwesompleteUtil.start('#user_hobby', {}, {minChars: 1});\"","ref":"PhoenixFormAwesomplete.html#awesomplete_js/3-example"},{"type":"function","title":"PhoenixFormAwesomplete.awesomplete_script/2","doc":"This method generates a script tag with javascript code for using Awesomplete(Util).","ref":"PhoenixFormAwesomplete.html#awesomplete_script/2"},{"type":"function","title":"Example - PhoenixFormAwesomplete.awesomplete_script/2","doc":"iex> ff = %Phoenix.HTML.FormField{form: \"user\", field: \"hobby\", id: \"user_hobby\", name: \"user[hobby]\", errors: [], value: nil} \n    iex> PhoenixFormAwesomplete.awesomplete_script(ff, %{ minChars: 1 } )\n    {:safe,\n     \" AwesompleteUtil.start('#user_hobby', {}, {minChars: 1}); \"}\n\n    iex> PhoenixFormAwesomplete.awesomplete_script(:user, :hobby, %{ minChars: 1, nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\" } )\n    {:safe,\n     \" AwesompleteUtil.start('#user_hobby', {}, {minChars: 1}); \"}","ref":"PhoenixFormAwesomplete.html#awesomplete_script/2-example"},{"type":"function","title":"PhoenixFormAwesomplete.awesomplete_script/3","doc":"This method generates a script tag with javascript code for using Awesomplete(Util).\nAs awesomplete_script/2 but with form and field parameters as used in Phoenix.HTML.Form functions\ninstead of the Phoenix.HTML.FormField.\nThe form parameter is either a Phoenix.HTML.Form struct or an atom.","ref":"PhoenixFormAwesomplete.html#awesomplete_script/3"},{"type":"function","title":"Example - PhoenixFormAwesomplete.awesomplete_script/3","doc":"iex> PhoenixFormAwesomplete.awesomplete_script(:user, :hobby, %{ minChars: 1 } )\n    {:safe,\n     \" AwesompleteUtil.start('#user_hobby', {}, {minChars: 1}); \"}\n\n    iex> PhoenixFormAwesomplete.awesomplete_script(:user, :hobby, %{ minChars: 1, nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\" } )\n    {:safe,\n     \" AwesompleteUtil.start('#user_hobby', {}, {minChars: 1}); \"}","ref":"PhoenixFormAwesomplete.html#awesomplete_script/3-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_to_field/5","doc":"As copy_value_to_field/3 but with form and field parameters as used in Phoenix.HTML.Form functions\ninstead of the Phoenix.HTML.FormField's. \nThe source_form and target_form parameters are either a Phoenix.HTML.Form struct or an atom.","ref":"PhoenixFormAwesomplete.html#copy_to_field/5"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_to_field/5","doc":"iex> PhoenixFormAwesomplete.copy_to_field(:user, :color, \"label\", :door, :paint)  \n    {:safe,\n     \" AwesompleteUtil.startCopy('#user_color', 'label', '#door_paint'); \"}","ref":"PhoenixFormAwesomplete.html#copy_to_field/5-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_to_field_script/6","doc":"Same as copy_to_field/5 but with an additional last argument for the script attributes.","ref":"PhoenixFormAwesomplete.html#copy_to_field_script/6"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_to_field_script/6","doc":"iex> PhoenixFormAwesomplete.copy_to_field_script(:user, :color, \"label\", :door, :paint, [nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\"])\n    {:safe,\n     \" AwesompleteUtil.startCopy('#user_color', 'label', '#door_paint'); \"}","ref":"PhoenixFormAwesomplete.html#copy_to_field_script/6-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_to_id/4","doc":"As copy_value_to_id/3 but with form and field parameters as used in Phoenix.HTML.Form functions\ninstead of the Phoenix.HTML.FormField.\nThe source_form parameter is either a Phoenix.HTML.Form struct or an atom.","ref":"PhoenixFormAwesomplete.html#copy_to_id/4"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_to_id/4","doc":"iex> PhoenixFormAwesomplete.copy_to_id(:user, :color, \"label\", \"#awe-color-result\") \n    {:safe,\n     \" AwesompleteUtil.startCopy('#user_color', 'label', '#awe-color-result'); \"}","ref":"PhoenixFormAwesomplete.html#copy_to_id/4-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_to_id_js/4","doc":"As copy_value_to_id_js/3 but with form and field parameters as used in Phoenix.HTML.Form functions\ninstead of the Phoenix.HTML.FormField.\nThe source_form and target_form parameters are either a Phoenix.HTML.Form struct or an atom.","ref":"PhoenixFormAwesomplete.html#copy_to_id_js/4"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_to_id_js/4","doc":"iex> PhoenixFormAwesomplete.copy_to_id_js(:user, :color, \"label\", \"#awe-color-result\") \n    \"AwesompleteUtil.startCopy('#user_color', 'label', '#awe-color-result');\"","ref":"PhoenixFormAwesomplete.html#copy_to_id_js/4-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_to_id_script/5","doc":"Same as copy_to_id/4 but with an additional last argument for the script attributes.","ref":"PhoenixFormAwesomplete.html#copy_to_id_script/5"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_to_id_script/5","doc":"iex> PhoenixFormAwesomplete.copy_to_id_script(:user, :color, \"label\", \"#awe-color-result\", [nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\"])\n    {:safe,\n     \" AwesompleteUtil.startCopy('#user_color', 'label', '#awe-color-result'); \"}","ref":"PhoenixFormAwesomplete.html#copy_to_id_script/5-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_value_to_field/3","doc":"Create script tag with javascript that listens to `awesomplete-prepop` and `awesomplete-match` events on the source form field,\nand copies the `data_field` to the target form field.","ref":"PhoenixFormAwesomplete.html#copy_value_to_field/3"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_value_to_field/3","doc":"iex> ff_source = %Phoenix.HTML.FormField{form: \"palet\", field: \"color\", id: \"palet_color\", name: \"palet[color]\", errors: [], value: nil} \n    iex> ff_target = %Phoenix.HTML.FormField{form: \"palet\", field: \"paint\", id: \"palet_paint\", name: \"palet[paint]\", errors: [], value: nil} \n    iex> PhoenixFormAwesomplete.copy_value_to_field(ff_source, \"label\", ff_target)  \n    {:safe,\n     \" AwesompleteUtil.startCopy('#palet_color', 'label', '#palet_paint'); \"}","ref":"PhoenixFormAwesomplete.html#copy_value_to_field/3-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_value_to_field_script/4","doc":"Same as copy_value_to_field/3 but with an additional last argument for the script attributes.","ref":"PhoenixFormAwesomplete.html#copy_value_to_field_script/4"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_value_to_field_script/4","doc":"iex> ff_source = %Phoenix.HTML.FormField{form: \"palet\", field: \"color\", id: \"palet_color\", name: \"palet[color]\", errors: [], value: nil} \n    iex> ff_target = %Phoenix.HTML.FormField{form: \"palet\", field: \"paint\", id: \"palet_paint\", name: \"palet[paint]\", errors: [], value: nil} \n    iex> PhoenixFormAwesomplete.copy_value_to_field_script(ff_source, \"label\", ff_target, [nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\"])\n    {:safe,\n     \" AwesompleteUtil.startCopy('#palet_color', 'label', '#palet_paint'); \"}","ref":"PhoenixFormAwesomplete.html#copy_value_to_field_script/4-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_value_to_id/3","doc":"Create script tag with javascript that listens to `awesomplete-prepop` and `awesomplete-match` events,\nand copies the `data_field` to the DOM element with the given target id.\nThe `target id` is passed to the DOM document querySelector, and is typically \nset as a hash character with an element id.\nThe `target_id` can also be a javascript function.","ref":"PhoenixFormAwesomplete.html#copy_value_to_id/3"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_value_to_id/3","doc":"iex> ff = %Phoenix.HTML.FormField{form: \"palet\", field: \"color\", id: \"palet_color\", name: \"palet[color]\", errors: [], value: nil} \n    iex> PhoenixFormAwesomplete.copy_value_to_id(ff, \"label\", \"#awe-color-result\") \n    {:safe,\n     \" AwesompleteUtil.startCopy('#palet_color', 'label', '#awe-color-result'); \"}","ref":"PhoenixFormAwesomplete.html#copy_value_to_id/3-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_value_to_id_js/3","doc":"Create javascript that listens to `awesomplete-prepop` and `awesomplete-match` events,\nand copies the `data_field` to the DOM element with the given target id.\nThe `target id` is passed to the DOM document querySelector, and is typically \nset as a hash character with an element id.\nThe `target_id` can also be a javascript function.","ref":"PhoenixFormAwesomplete.html#copy_value_to_id_js/3"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_value_to_id_js/3","doc":"iex> ff = %Phoenix.HTML.FormField{form: \"palet\", field: \"color\", id: \"palet_color\", name: \"palet[color]\", errors: [], value: nil} \n    iex> PhoenixFormAwesomplete.copy_value_to_id_js(ff, \"label\", \"#awe-color-result\") \n    \"AwesompleteUtil.startCopy('#palet_color', 'label', '#awe-color-result');\"","ref":"PhoenixFormAwesomplete.html#copy_value_to_id_js/3-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_value_to_id_script/4","doc":"Same as copy_value_to_id/4 but with an additional last argument for script attributes.","ref":"PhoenixFormAwesomplete.html#copy_value_to_id_script/4"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_value_to_id_script/4","doc":"iex> ff = %Phoenix.HTML.FormField{form: \"palet\", field: \"color\", id: \"palet_color\", name: \"palet[color]\", errors: [], value: nil} \n    iex> PhoenixFormAwesomplete.copy_value_to_id_script(ff, \"label\", \"#awe-color-result\", [nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\"])\n    {:safe,\n     \" AwesompleteUtil.startCopy('#palet_color', 'label', '#awe-color-result'); \"}","ref":"PhoenixFormAwesomplete.html#copy_value_to_id_script/4-example"},{"type":"function","title":"PhoenixFormAwesomplete.script/1","doc":"Create script tag with the supplied script. No defer or async because this is used for inline script.","ref":"PhoenixFormAwesomplete.html#script/1"},{"type":"function","title":"Example - PhoenixFormAwesomplete.script/1","doc":"iex> PhoenixFormAwesomplete.script(\"alert(1);\")\n    {:safe, \" alert(1); \"}","ref":"PhoenixFormAwesomplete.html#script/1-example"},{"type":"function","title":"PhoenixFormAwesomplete.script/2","doc":"Same as script/1 with a second argument for the script attributes.","ref":"PhoenixFormAwesomplete.html#script/2"},{"type":"function","title":"Example - PhoenixFormAwesomplete.script/2","doc":"iex> PhoenixFormAwesomplete.script(\"alert(1);\" , [nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\"])\n    {:safe, \" alert(1); \"}\n\n    iex> PhoenixFormAwesomplete.script(\"alert(2);\" , %{nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\"})\n    {:safe, \" alert(2); \"}","ref":"PhoenixFormAwesomplete.html#script/2-example"},{"type":"module","title":"PhoenixFormAwesomplete.GenJS","doc":"Generate the javascript code for PhoenixFormAwesomplete.","ref":"PhoenixFormAwesomplete.GenJS.html"},{"type":"module","title":"Example - PhoenixFormAwesomplete.GenJS","doc":"iex> PhoenixFormAwesomplete.GenJS.awesomplete_js(\"user_drinks\", %{ minChars: 1, prepop: true } )\n    \"AwesompleteUtil.start('#user_drinks', {prepop: true}, {minChars: 1});\"","ref":"PhoenixFormAwesomplete.GenJS.html#module-example"},{"type":"function","title":"PhoenixFormAwesomplete.GenJS.awesomplete_js/2","doc":"This method generates javascript code for using Awesomplete(Util).","ref":"PhoenixFormAwesomplete.GenJS.html#awesomplete_js/2"},{"type":"function","title":"Example - PhoenixFormAwesomplete.GenJS.awesomplete_js/2","doc":"iex> PhoenixFormAwesomplete.GenJS.awesomplete_js(\"user_hobby\", %{ minChars: 1 } ) \n    \"AwesompleteUtil.start('#user_hobby', {}, {minChars: 1});\"","ref":"PhoenixFormAwesomplete.GenJS.html#awesomplete_js/2-example"},{"type":"function","title":"PhoenixFormAwesomplete.GenJS.copy_to_id_js/3","doc":"Create javascript that listens to `awesomplete-prepop` and `awesomplete-match` events,\nand copies the `data_field` to the DOM element with the given target id.\nThe `target_id` can also be a javascript function.","ref":"PhoenixFormAwesomplete.GenJS.html#copy_to_id_js/3"},{"type":"function","title":"Example - PhoenixFormAwesomplete.GenJS.copy_to_id_js/3","doc":"iex> PhoenixFormAwesomplete.GenJS.copy_to_id_js(\"#user_color\", \"label\", \"#awe-color-result\") \n    \"AwesompleteUtil.startCopy('#user_color', 'label', '#awe-color-result');\"","ref":"PhoenixFormAwesomplete.GenJS.html#copy_to_id_js/3-example"}],"content_type":"text/markdown"}